template

package
v0.0.0-...-215383d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 22, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewTemplateModel

func NewTemplateModel(s *spinner.Model, children ...tea.Model) tea.Model

NewTemplateModel creates a template. A template handle the state of a spinner that can be shared with multiple models and a list of children that are also bubbletea models.

Each child is rendered in the same order as they are defined. Their `Init` method is called during the template `Init` method.

⚠️ Known bugs ⚠️

BUG(Anthony-Jhoiro)::️ children's shouldn't listen for events in a blocking way (for now), that's mean that if a child listen to an event and returns a command, the `Update`method won't be called on other children.

Types

This section is empty.

Notes

Bugs

  • :️ children's shouldn't listen for events in a blocking way (for now), that's mean that if a child listen to an event and returns a command, the `Update`method won't be called on other children.

Jump to